import { action, flow, makeObservable, observable } from 'mobx';
import BaseStore from './base_store';
import client from '../axiosClient';
import ExchangeAccount from '../entities/exchange_account';
import consumer from '../../channels/consumer';

class AppStore extends BaseStore {
  @observable sidebarOpened = true;

  @observable exchangeAccount;

  @observable currentExchangeAccountId;

  @observable totalWinAmount = 0;

  @observable totalLostAmount = 0;

  @observable totalRiskedAmount = 0;

  @observable totalTips = 0;

  @observable totalTipsSkipped = 0;

  @observable totalTipsProcessing = 0;

  @observable totalTipsExpired = 0;

  @observable totalTipsIgnored = 0;

  @observable totalTipsVoided = 0;

  @observable totalPlacedBets = 0;

  @observable totalPlacedBetsWon = 0;

  @observable totalPlacedBetsLost = 0;

  @observable totalPlacedBetsOpen = 0;

  @observable averageOddsWon = 0;

  @observable averageOddsLost = 0;

  @observable averageOdds = 0;


  @observable appInitialised = false;

  @observable autoRefreshResults = true;

  @observable runningSince = null;

  @observable exchangeAccounts = [];

  constructor(store) {
    super(store, null);
    this.consumer = consumer;
    makeObservable(this);
    this.fetchConfigFromServer();
  }

  @action
  asPercentOfTotal(val) {
    if (val === 0 || this.totalPlacedBets === 0) return '0%';
    return `${Math.round((val / this.totalPlacedBets) * 100)}%`;
  }

  @flow
  *fetchConfigFromServer() {
    const response = yield client.get('/api/v1/app/configuration.json');
    if (response.data.success) {
      this.update(response.data.config);
    }
  }

  @flow
  *fetchSummaryFiguresFromServer() {
    const response = yield client.get('/api/v1/app/summary.json', {
      params: {
        exchange_account_id:
          this.currentExchangeAccountId || this.exchangeAccount?.id || '',
      },
    });
    if (response.data.success) {
      this.updateSummary(response.data.summary);
    }
  }

  updateSummary(summary) {
    console.log('Refreshing dashboard');
    this.update(summary);
    const ea = new ExchangeAccount(summary.exchange_account);
    this.update({
      exchangeAccount: ea,
      appInitialised: true,
      currentExchangeAccountId: ea.id,
    });
  }

  refresh() {
    console.log('Refreshing filtered results');
    this.rootStore.betStore.fetch(this.rootStore.betStore.params);
    return null;
  }

  startListeningToAccountChannel() {
    const obj = this;
    this.consumer.subscriptions.create(
      { channel: 'ExchangeAccountChannel', id: obj.exchangeAccount.id },
      {
        connected() {
          console.log('Connected to ExchangeAccountChannel');
        },
        disconnected() {
          console.log('Disconnected from ExchangeAccountChannel');
        },
        received(data) {
          console.log('Cable received');
          return null;
        },
      }
    );
  }
}

export default AppStore;
