import {
  extendObservable,
  flow,
  makeObservable,
  observable,
  override,
} from 'mobx';

import { map, orderBy } from 'lodash';
import BaseStore from './base_store';
import Bet from '../entities/bet';
import Filterable from '../concerns/filterable';
import Pagination from '../entities/pagination';

class BetStore extends BaseStore {
  @observable params = {
    event_name: '',
    outcome: '',
    created_at: { from: null, to: null },
  };


  constructor(store) {
    super(store, Bet);

    extendObservable(this, Filterable);

    this.initializeFilterable(this.params);
    makeObservable(this);
  }

  @override
  get filteredRecords() {
    return orderBy(this.records, ['createdAt'], ['desc']);
  }

  @flow
  *fetch(pms) {
    this.params = pms;
    const response = yield this.client.get('/api/v1/bets.json', {
      params: {
        ...this.params,
        exchange_account_id: this.rootStore.appStore.currentExchangeAccountId,
      },
    });

    if (response.data.summary) {
      this.rootStore.appStore.updateSummary(response.data.summary);
    }

    if (response.data.bets) {
      this.update({
        records: map(response.data.bets, bet => this.addRecord(bet)),
      });
    }
    if (response.data.pagy) {
      const p = new Pagination({ ...response.data.pagy }, this);
      this.pagination.count = p.count;
      this.pagination.prev = p.prev;
      this.pagination.next = p.next;
      this.pagination.last = p.last;
      this.pagination.from = p.from;
      this.pagination.to = p.to;
      this.pagination.page = p.page;
      this.pagination.pages = p.pages;
    }
  }
}

export default BetStore;
