import { computed, flow, makeObservable, observable } from 'mobx';

import { isEmpty } from 'lodash';
import BaseStore from './base_store';
import User from '../entities/user';

class UserStore extends BaseStore {
  /* eslint-disable */
  @observable currentUser = {};
  @observable fetchingCurrentUser = true;
  /* eslint-enable */

  constructor(store) {
    super(store, User);

    makeObservable(this);
  }

  @computed
  get userSignedIn() {
    return !isEmpty(this.currentUser);
  }

  @flow
  *fetchCurrentUser() {
    const response = yield this.client.get('/api/v1/users/auth.json');

    if (response.data.success) {
      this.update({ currentUser: new User(response.data.user, this) });
    }

    this.fetchingCurrentUser = false;
  }
}

export default UserStore;
