import { isEmpty, map } from 'lodash';
import React from 'react';
import PropTypes from 'prop-types';
import { observer } from 'mobx-react';
import ReactTimeAgo from 'react-time-ago';
import { Table } from 'reactstrap';
import moment from 'moment';

const BetsList = ({ records }) => {
  if (isEmpty(records))
    return <p className="mt-5 font-weight-bold"> No bets </p>;

  return (
    <Table striped>
      <thead>
        <tr className="small">
          <th>Event</th>
          <th>Tip Market / Exchange Market Info</th>
          <th>Tip EV</th>
          <th>Tip Odds</th>
          <th>Exchange Odds</th>
          <th>Executed Odds</th>
          <th>Stake</th>
          <th>Projected Profit</th>
          <th>Outcome</th>
          <th>Updated</th>
          <th>Type</th>
        </tr>
      </thead>
      <tbody>
        {map(records, (record, i) => (
          <tr key={i}>
            <td>
              {record.exchangeEventName}
              <br />
              {!isEmpty(record.eventScheduledTime) && (
                <>
                  <span className="small">
                    {moment(new Date(record.eventScheduledTime)).format(
                      'DD.MMM.YYYY  HH:mm:ss'
                    )}
                  </span>
                  <br />
                </>
              )}
              <span className="small">
                <span className="text-muted small">
                  {record.exchange}|{record.id}
                </span>
              </span>
            </td>
            <td>
              {' '}
              {record.marketIdentifier} <br />
              <span className="text-muted small">
                {record.exchangeMarketDetails}
              </span>
            </td>
            <td> {record.evPercent} </td>
            <td> {record.tipProviderOdds} </td>
            <td style={{ fontSize: 12 }}> {record.exchangeOdds} </td>
            <td> {record.executedOdds} </td>
            <td> {record.stake} </td>
            <td> {record.expectedValue} </td>
            <td>
              <span className="btn-link" title={record.log}>
                {record.outcome}{' '}
              </span>
            </td>
            <td>
              <ReactTimeAgo date={new Date(record.createdAt)} />
            </td>
            <td> {record.betPlacementType} </td>
          </tr>
        ))}
      </tbody>
    </Table>
  );
};
BetsList.propTypes = {
  records: PropTypes.instanceOf(Array).isRequired,
};

export default observer(BetsList);
