import React from 'react';

import { observer } from 'mobx-react';
import {
  Navbar,
  Nav,
  UncontrolledDropdown,
  DropdownToggle,
  DropdownMenu,
  DropdownItem,
  Button,
  Row,
  Col,
} from 'reactstrap';
import { Initial } from 'react-initial';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { useHistory } from 'react-router-dom';
import { isEmpty } from 'lodash';
import useStore from '../../../data/store';
import { useWindowSize } from '../../../helpers/shared_helpers';

const _header = () => {
  const { appStore } = useStore();

  return (
    <header className="container-lg pt-4">
      <Row className="sticky-top ">
        <div>
          <strong> Results Dashboard</strong>
          <hr />
        </div>
        <Col size={3}>
          <div className="font-weight-bold">
            Total Risked: £{appStore.totalRiskedAmount}
          </div>
          <div>Total Won: £{appStore.totalWinAmount}</div>
          <div>Total Lost: £{appStore.totalLostAmount}</div>
          <div>
            <strong>
              Total Profit:{' '}
              <span
                className={
                  appStore.totalWinAmount - appStore.totalLostAmount >= 0
                    ? 'text-success'
                    : 'text-danger'
                }
              >
                £
                {Math.round(appStore.totalWinAmount - appStore.totalLostAmount)}
              </span>
            </strong>
          </div>
        </Col>
        <Col size={3}>
          <div>Total Tips: {appStore.totalTips}</div>
          <div>Total Tips Executed: {appStore.totalPlacedBets}</div>
          <div>Total Tips Skipped: {appStore.totalTipsSkipped}</div>
        </Col>
        <Col size={3}>
          <div className="fw-bold">
            Total Bets Placed: {appStore.totalPlacedBets}
          </div>
          <div>Total Tips Expired: {appStore.totalTipsExpired}</div>
          <div>Total Tips Ignored: {appStore.totalTipsIgnored}</div>
          <div>Total Tips Voided: {appStore.totalTipsVoided}</div>
        </Col>
        <Col size={3}>
          <div>Total Bets Open: {appStore.totalPlacedBetsOpen}</div>
          <div>
            Total Bets Won: {appStore.totalPlacedBetsWon}
            <span className="small text-info">
              {' '}
              ({appStore.asPercentOfTotal(appStore.totalPlacedBetsWon)})
            </span>
          </div>
          <div className="mx-3 text-muted small">
            Average Odds Won at: {appStore.averageOddsWon}
          </div>
          <div>
            Total Bets Lost: {appStore.totalPlacedBetsLost}
            <span className="small text-info">
              {' '}
              ({appStore.asPercentOfTotal(appStore.totalPlacedBetsLost)})
            </span>
          </div>
          <div className="mx-3 text-muted small">
            Average Odds Lost at: {appStore.averageOddsLost}
          </div>
        </Col>
      </Row>
      <hr />
    </header>
  );
};

export default observer(_header);
