import React, { useEffect } from 'react';

import { Link } from 'react-router-dom';
import { observer } from 'mobx-react';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import ReactTimeAgo from 'react-time-ago';
import { map } from 'lodash';
import moment from 'moment';
import { Form, FormGroup, Input, Label } from 'reactstrap';
import LOGO from '../../../assets/images/logo.svg';
import useStore from '../../../data/store';
import { SelectTag } from '../../shared/form_components';
import CountdownRefresh from '../../modules/countdown_refresh';
import EditableHash from '../../modules/editable_hash';
import Toggler from '../../modules/toggler.js';

const _sidebar = () => {
  const { appStore } = useStore();

  useEffect(() => {
    appStore.refresh();
  }, []);

  const changeExchangeAccount = e => {
    appStore.update({ currentExchangeAccountId: e.target.value });
    appStore.refresh();
  };

  const exchangeAccountsAsOptions = () => ({
    name: 'exchangeAccounts',
    value: appStore.currentExchangeAccountId,
    type: 'select',
    placeholder: 'Select...',
    label: 'Available Accounts',
    options: map(appStore.exchangeAccounts, r => ({ label: r, value: r })),
  });

  return (
    <>
      {!appStore.appInitialised && <div>Refreshing...</div>}
      {appStore.appInitialised && (
        <div className="sidebar bg-light">
          <div className="sidebar-width">
            <div className="logo text-center">
              <Link to="/dashboard">
                <img src={LOGO} alt="logo" />
              </Link>
            </div>
            <div className="separator" />
            <div className="sidebar-links">
              <div className="p-0 small">
                <div className="text-primary mb-3">
                  <div className="mb-1">Available Accounts:</div>
                  <SelectTag
                    handleChange={changeExchangeAccount}
                    input={exchangeAccountsAsOptions()}
                  />
                </div>
                <div>
                  <Toggler
                    prompt
                    state={appStore.exchangeAccount.isActive}
                    onText="Activate account"
                    offText="Deactivate account"
                    onChangeHandler={() => {
                      appStore.exchangeAccount.updateExchangeAccount({
                        isActive: !appStore.exchangeAccount.isActive,
                      });
                    }}
                  />
                </div>
                <div>
                  <Toggler
                    prompt
                    disabled={!appStore.exchangeAccount.isActive}
                    state={appStore.exchangeAccount.canBet}
                    onText="Enable live betting"
                    offText="Disable live betting"
                    onChangeHandler={() => {
                      appStore.exchangeAccount.updateExchangeAccount({
                        canBet: !appStore.exchangeAccount.canBet,
                      });
                    }}
                  />
                </div>
                <div>
                  <CountdownRefresh
                    refreshTrigger={appStore.autoRefreshResults}
                    refreshFunction={appStore.refresh}
                  />
                </div>
                <hr />
                <div className="small">
                  <div className="font-weight-bold text-primary  mb-1">
                    Account Balance: £{appStore.exchangeAccount.accountBalance}
                  </div>
                  <div className="text-primary">
                    Running since:{' '}
                    <ReactTimeAgo date={new Date(appStore.runningSince)} />
                  </div>
                  <div className="text-primary">
                    Feed type: {appStore.exchangeAccount.sourceTypes}
                  </div>
                  <div className="text-primary">
                    Stake Strategy: {appStore.exchangeAccount.stakeStrategyName}
                  </div>
                  <div className="text-primary mb-1">
                    Strategy Config:
                    <EditableHash
                      source={appStore.exchangeAccount.stakeStrategyConfig}
                      updateFunction={() => {
                        alert('this');
                      }}
                    />
                  </div>
                  <div className="mt-3">
                    <div className="small text-secondary">
                      <strong>
                        Last log was at{' '}
                        {moment(
                          new Date(appStore.exchangeAccount.lastLogTime)
                        ).format('DD.MMM.YYYY  HH:mm:ss')}
                      </strong>
                    </div>
                    <code className="small text-muted  mb-1">
                      {appStore.exchangeAccount.log}
                    </code>
                  </div>
                </div>
              </div>
            </div>

            <div className="separator" />
            <div className="sidebar-links">
              <ul>
                <li className="d-flex">
                  <a href="/admin/sidekiq" target="sidekiq">
                    <FontAwesomeIcon icon="cogs" /> Sidekiq
                  </a>
                </li>
              </ul>
            </div>
          </div>
        </div>
      )}
      ;
    </>
  );
};

export default observer(_sidebar);
