import React from 'react';

import { observer } from 'mobx-react';
import PropTypes from 'prop-types';

import { Button } from 'reactstrap';
import classnames from 'classnames';
import Header from './_header';
import Sidebar from './_sidebar';
import useStore from '../../../data/store';

const AuthenticatedLayout = ({ children, loading }) => {
  const { appStore } = useStore();

  return (
    <div className="authenticated-layout">
      <div
        className={classnames('bootstrap-layout', {
          'sidebar-opened': appStore.sidebarOpened,
          'sidebar-closed': !appStore.sidebarOpened,
        })}
      >
        <div className="bl-sidebar">
          <Sidebar />
        </div>
        <div className="bl-content">
          <Header />
          <main>{loading ? 'Loading' : children}</main>
        </div>
      </div>
    </div>
  );
};

AuthenticatedLayout.defaultProps = {
  loading: false,
};

AuthenticatedLayout.propTypes = {
  children: PropTypes.node,
  loading: PropTypes.bool,
};

export default observer(AuthenticatedLayout);
