import React, { Fragment, useState } from 'react';

import PropTypes from 'prop-types';
import { isBoolean, map } from 'lodash';
import { Col, FormGroup, Label, Row } from 'reactstrap';
import { observer } from 'mobx-react';

import { renderFilter } from '../../../helpers/filter_helpers';

const Filters = ({ pagination, filters }) => {
  const [timeout, setTimeOut] = useState(null);

  const handleChange = e => {
    let timer = null;

    setTimeOut(clearTimeout(timeout));

    pagination.update({
      params: { ...pagination.params, [e.target.name]: e.target.value },
    });

    timer = setTimeout(() => {
      pagination.resetPageAndFetch();
    }, 1000);

    setTimeOut(timer);
  };

  return (
    <Row className="">
      {map(filters, (filter, i) => (
        <Fragment>
          {isBoolean(filter.show) && !filter.show ? null : (
            <Col key={i}>
              <FormGroup>
                <Label>{filter.label}</Label>
                {renderFilter(
                  { ...filter, value: pagination.params[filter.name] },
                  handleChange
                )}
              </FormGroup>
            </Col>
          )}
        </Fragment>
      ))}
    </Row>
  );
};

Filters.propTypes = {
  pagination: PropTypes.instanceOf(Object).isRequired,
  filters: PropTypes.instanceOf(Array).isRequired,
};

export default observer(Filters);
