import React, { useEffect } from 'react';

import { observer } from 'mobx-react';

import { isEmpty, isNull } from 'lodash';
import { Button } from 'reactstrap';
import PropTypes from 'prop-types';
import Filters from './_filters';

const FilteredList = ({
  store,
  listComponent,
  gridComponent,
  filters,
  changeTrigger,
  listClassName,
  recordClassName,
}) => {
  const ListComponent = listComponent;
  // const Component = gridComponent;

  useEffect(() => {
    store.pagination.fetch();
  }, [changeTrigger]);

  return (
    <div className="filtered-lists">
      <Filters filters={filters} pagination={store.pagination} />
      <nav aria-label="Page navigation example">
        <ul className="pagination justify-content-start">
          <li className="small text-muted mt-2" style={{marginRight: 10}}>
            <strong>
              {store.pagination.from} to {store.pagination.to} of{' '}
              {store.pagination.count}{' '}
            </strong>
          </li>
          <li className="">
            <Button
              className="btn-link page-link"
              onClick={() => store.pagination.gotoPage(1)}
              disabled={isNull(store.pagination.prev)}
            >
              First
            </Button>
          </li>
          <li className="page-item">
            <Button
              className="btn-link page-link"
              disabled={isNull(store.pagination.prev)}
              onClick={() => store.pagination.gotoPage(store.pagination.prev)}
            >
              Prev
            </Button>
          </li>
          <li className="page-item">
            <Button
              className="btn-link page-link"
              disabled={isNull(store.pagination.next)}
              onClick={() => store.pagination.gotoPage(store.pagination.next)}
            >
              Next
            </Button>
          </li>
          <li className="page-item">
            <Button
              className="btn-link page-link"
              disabled={
                isNull(store.pagination.last) || store.pagination.count === 0
              }
              onClick={() => store.pagination.gotoPage(store.pagination.last)}
            >
              Last
            </Button>
          </li>
        </ul>
      </nav>
      {isEmpty(store.filteredRecords) && (
        <>
          <hr />
          <strong className="text-muted">Nothing here.</strong>
        </>
      )}
      {!isEmpty(store.filteredRecords) && (
        <div className="records mt-4">
          <div className={listClassName}>
            <div className="table-responsive">
              <ListComponent records={store.filteredRecords} />
            </div>
          </div>
        </div>
      )}
    </div>
  );
};

FilteredList.defaultProps = {
  listClassName: '',
  recordClassName: '',
};

FilteredList.propTypes = {
  store: PropTypes.instanceOf(Object).isRequired,
  listComponent: PropTypes.func.isRequired,
  gridComponent: PropTypes.func,
  filters: PropTypes.instanceOf(Array).isRequired,
  changeTrigger: PropTypes.string.isRequired,
  listClassName: PropTypes.string,
  recordClassName: PropTypes.string,
};

export default observer(FilteredList);
