Rails.application.routes.draw do
  require 'sidekiq/web'
  require 'sidekiq/cron/web'

  authenticate :user do
    mount Sidekiq::Web => '/admin/sidekiq', as: 'sidekiq'
  end

  root 'pages#index'

  Devise.setup do |_config|
    devise_for :users, controllers: { omniauth_callbacks: 'users/omniauth_callbacks' },
               skip: %i(sessions registrations passwords) do
    end
  end

  devise_scope :user do
    get 'sign_out', to: 'devise/sessions#destroy'
  end

  namespace :api, constraints: { format: 'json' } do
    namespace :v1 do
      resources :app do
        collection do
          get :configuration
          get :summary
        end
      end
      resources :users, only: [:create] do
        collection do
          get :auth
        end
      end
      resource :exchange_account, only: [:update]
      resources :bets, only: [:index, :show]
      post 'bets/add_placed_bet', to: 'bets#add_placed_bet'
      post 'tips', to: 'bets#tips'
    end
  end
  get '*other', to: 'pages#index', constraints: lambda { |req|
    req.path.exclude? 'rails/active_storage'
  }
end
