# frozen_string_literal: true

require 'mail'
require 'bunny'

# in module for neatness
module Bettermail
  # The General purpose consumer
  class Consumer
    def initialize
    end

    def default_smtp_settings
      {
        address: ENV['DEFAULT_SMTP_HOST'],
        port: ENV['DEFAULT_SMTP_PORT'],
        user_name: ENV['DEFAULT_SMTP_UID'],
        password: ENV['DEFAULT_SMTP_PWD'],
        enable_starttls_auto: true,
        authentication: 'plain',
      }
    end



    def start
      begin
        puts ' [*] Waiting for messages. To exit press CTRL+C'
        new_mail_queue = bunny_channel.queue(ENV['RABBIT_MAIL_QUEUE'])
        new_mail_queue.subscribe(block: true) do |_delivery_info, _properties, body|
          instructions = JSON.parse(body)
          recipient = Recipient.create_or_find_by(id: instructions["recipient"])
          email = ReceivedMail.find_by(message_id: instructions["message"])
          recipient.emails.create(received_mail: email, delivery_status: 'queued')
        end
        sns_queue = bunny_channel.queue(ENV['RABBIT_SNS_QUEUE'])
        sns_queue.subscribe(block: true) do |_delivery_info, _properties, body|
          puts " [x] Received #{_delivery_info}"
        end
      rescue Interrupt => _
        stop
      end
    end

    def send_mail(mail)
      mail.delivery_method :smtp, default_smtp_settings
      mail.deliver!
    end

    def stop
      @bunny_conn&.close
    end

    def bunny_channel
      if @bunny_channel.nil?
        @bunny_conn = Bunny.new
        @bunny_conn.start
        @bunny_channel = @bunny_conn.create_channel
      end
      @bunny_channel
    end
  end
end
