# frozen_string_literal: true

require 'midi-smtp-server'
require 'mail'
require 'bunny'
require 'securerandom'

# in module for neatness
module Bettermail
  # The SMTPProxy
  class Proxy < MidiSmtpServer::Smtpd

    def stop(wait_seconds_before_close: nil, gracefully: nil)
      super()
      @bunny_conn&.close
    end

    def bunny
      if @bunny.nil?
        @bunny_conn = Bunny.new
        @bunny_conn.start
        ch = @bunny_conn.create_channel
        ch.direct(ENV['RABBIT_CHANNEL'])
        ch.queue(ENV['RABBIT_MAIL_QUEUE'])
        @bunny = ch.default_exchange
      end
      @bunny
    end

    # update local welcome and helo response
    def on_connect_event(ctx)
      ctx[:server][:local_response] = 'Client connected'
      ctx[:server][:helo_response] = 'Welcome to the BetterMail proxy - an SMTP drop in replacement'
    end

    def on_message_data_headers_event(ctx)
      # check and append all headers
      ctx[:message][:data] << "X-bettermail: Received by proxy at #{Time.now}" << ctx[:message][:crlf]
    end

    # check the authentication
    # if any value returned, that will be used for ongoing processing
    # otherwise the original value will be used for authorization_id
    def on_auth_event(ctx, authorization_id, authentication_id, authentication)
      # to proceed this test use commands ...
      # auth plain
      # > AGFkbWluaXN0cmF0b3IAcGFzc3dvcmQ=
      # auth login
      # > YWRtaW5pc3RyYXRvcg==
      # > cGFzc3dvcmQ=
      # if authorization_id == '' && authentication_id == 'administrator' && authentication == 'password'
      #   # yes
      #   return 'supervisor'
      # end
      # # otherwise exit with authentication exception
      # raise MidiSmtpServer::Smtpd535Exception
      logger.debug("Authenticated id: #{authentication_id} with authentication: #{authentication} from: #{ctx[:server][:remote_ip]}:#{ctx[:server][:remote_port]}")
      authentication_id
    end

    def save_mail(ctx, sender)
      mail = Mail.read_from_string(ctx[:message][:data])
      sender = Sender.create_or_find_by(id: sender)
      message_id = "#{SecureRandom.uuid}@bettermail.wizewerx.tech"
      saved_mail = sender.sent_mails.create(message_id: message_id, body: mail.to_s)
      message_id
    end

    def on_mail_from_event(ctx, mail_from_data)
      # tag the message here OR write it once to the database
      ctx[:message][:message_id] = save_mail(ctx, mail_from_data)
    end

    # simple rewrite and return value
    def on_rcpt_to_event(ctx, data)
      bunny.publish({message: ctx[:message][:message_id], recipient: data}.to_json, :headers => { }, :routing_key => ENV["RABBIT_MAIL_QUEUE"])
    end
  end
end
